GuardCtx

Struct GuardCtx 

pub struct GuardCtx {
Show 16 fields pub session_id: SessionId, pub turn_count: u32, pub user_input: String, pub model_response: String, pub finish_reason: FinishReason, pub available_tools: Vec<String>, pub reasoning_only_strikes: usize, pub empty_response_strikes: usize, pub run_has_tool_calls: bool, pub all_user_inputs: Vec<String>, pub is_reasoning_only: bool, pub is_empty_response: bool, pub is_text_only: bool, pub thinking_disabled: bool, pub original_thinking_enabled: bool, pub remaining_turns: u32,
}
Guard context information — built by runtime, passed to guard.

Fields

session_id: SessionIdturn_count: u32user_input: Stringmodel_response: Stringfinish_reason: FinishReasonavailable_tools: Vec<String>reasoning_only_strikes: usizeempty_response_strikes: usizerun_has_tool_calls: boolall_user_inputs: Vec<String>

All user messages in the current session, ordered oldest-first. Guards can use this to reconstruct full conversation context (e.g. “继续” after a multi-turn discussion).

is_reasoning_only: boolis_empty_response: boolis_text_only: boolthinking_disabled: booloriginal_thinking_enabled: bool

Original thinking configuration (for restoration)

From RunState.original_thinking_enabled

remaining_turns: u32

Remaining turns before hitting max_turns limit

Guards can use this to nudge the model to wrap up when running low on turns. When remaining_turns == 0, the run will be terminated with MaxTurnsExceeded.